# bgqsp
Utilities for handling CUSIP check digits. 


## Sample usage

```
>>> import bgqsp.cusip as q
>>> q.validate_cusip('912810DB')
'912810DB1'
>>>
```

## Disclaimers

This project is in no way associated with the American Bankers Association
and is offered as-is with no guarantees.

CUSIP is a registered trademark of the American Bankers Association. 
